package com.example.foodnowaster;

import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;

import com.example.foodnowaster.DBHelper;
import com.example.foodnowaster.R;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.GregorianCalendar;

public class AddModifyDeleteFoodItem extends AppCompatActivity {

    DBHelper mydb;
    Calendar calendar;

    Button save_btn;
    Boolean isModify = false;
    EditText edit_text;
    String foodItem_id;
    TextView toolbar_title;
    TextView dateText;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().getDecorView().setSystemUiVisibility(View.SYSTEM_UI_FLAG_LIGHT_STATUS_BAR);
        setContentView(R.layout.activity_add_modify_delete_food_item);

        mydb = new DBHelper(getApplicationContext());
        calendar = new GregorianCalendar();
        toolbar_title = findViewById(R.id.toolbar_title);
        save_btn = findViewById(R.id.save_btn);
        dateText = findViewById(R.id.dateText);
        edit_text = findViewById(R.id.edit_text);

        dateText.setText("Due date:\n" + new SimpleDateFormat("E, dd MMMM yyyy").format(calendar.getTime()));

        Intent intent = getIntent();
        if (intent.hasExtra("isModify")) {
            isModify = intent.getBooleanExtra("isModify", false);
            foodItem_id = intent.getStringExtra("id");
            init_modify();
        }


    }

    public void init_modify() {
        toolbar_title.setText("Food item details");
        save_btn.setText("Update");
        LinearLayout deleteFoodItem = findViewById(R.id.deleteFoodItem);
        deleteFoodItem.setVisibility(View.VISIBLE);
        Cursor foodItem = mydb.getSingleFoodItem(foodItem_id);
        if (foodItem != null) {
            foodItem.moveToFirst();

            edit_text.setText(foodItem.getString(1));

            SimpleDateFormat iso8601Format = new SimpleDateFormat("yyyy-MM-dd");
            try {
                calendar.setTime(iso8601Format.parse(foodItem.getString(2)));
            } catch (ParseException e) {
            }

            dateText.setText("Due date:\n" + new SimpleDateFormat("E, dd MMMM yyyy").format(calendar.getTime()));
        }

    }


    public void saveFoodItem(View v) {

        /*Checking if food item is empty*/
        if (edit_text.getText().toString().trim().length() > 0) {

            if (isModify) {
                mydb.updateFoodItem(foodItem_id, edit_text.getText().toString(), new SimpleDateFormat("yyyy-MM-dd").format(calendar.getTime()));
                Toast.makeText(getApplicationContext(), "Food item is Updated", Toast.LENGTH_SHORT).show();
            } else {
                mydb.insertFoodItem(edit_text.getText().toString(), new SimpleDateFormat("yyyy-MM-dd").format(calendar.getTime()));
                Toast.makeText(getApplicationContext(), "Food item is Added", Toast.LENGTH_SHORT).show();
            }
            finish();

        } else {
            Toast.makeText(getApplicationContext(), "Food item can't be empty", Toast.LENGTH_SHORT).show();
        }

    }

    public void deleteFoodItem(View v) {
        mydb.deleteFoodItem(foodItem_id);
        Toast.makeText(getApplicationContext(), "Food item is Removed", Toast.LENGTH_SHORT).show();
        finish();
    }


    public void chooseDate(View view) {
        final View dialogView = View.inflate(this, R.layout.date_picker, null);
        final DatePicker datePicker = dialogView.findViewById(R.id.date_picker);
        datePicker.updateDate(calendar.get(Calendar.YEAR), calendar.get(Calendar.MONTH), calendar.get(Calendar.DAY_OF_MONTH));

        final AlertDialog.Builder builder = new AlertDialog.Builder(this);
        builder.setView(dialogView);
        builder.setTitle("Choose Date");
        builder.setNegativeButton("Cancel", null);
        builder.setPositiveButton("Set", new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int id) {
                calendar = new GregorianCalendar(datePicker.getYear(), datePicker.getMonth(), datePicker.getDayOfMonth());
                dateText.setText("Due date:\n" + new SimpleDateFormat("E, dd MMMM yyyy").format(calendar.getTime()));
            }
        });
        builder.show();
    }
}
