package com.example.foodnowaster;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.database.Cursor;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.LinearLayout;

import androidx.appcompat.app.AppCompatActivity;
import androidx.core.widget.NestedScrollView;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.HashMap;

public class MainActivity extends AppCompatActivity {

    DBHelper mydb;
    LinearLayout empty;
    NestedScrollView scrollView;
    LinearLayout todayContainer, tomorrowContainer, laterContainer;
    NoScrollListView foodItemListToday, foodItemListTomorrow, foodItemListLater;
    ArrayList<HashMap<String, String>> todayList = new ArrayList<HashMap<String, String>>();
    ArrayList<HashMap<String, String>> tomorrowList = new ArrayList<HashMap<String, String>>();
    ArrayList<HashMap<String, String>> laterList = new ArrayList<HashMap<String, String>>();


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().getDecorView().setSystemUiVisibility(View.SYSTEM_UI_FLAG_LIGHT_STATUS_BAR);
        setContentView(R.layout.activity_main);

        mydb = new DBHelper(this);
        empty = findViewById(R.id.empty);
        scrollView = findViewById(R.id.scrollView);
        todayContainer = findViewById(R.id.todayContainer);
        tomorrowContainer = findViewById(R.id.tomorrowContainer);
        laterContainer = findViewById(R.id.laterContainer);
        foodItemListToday = findViewById(R.id.foodItemListToday);
        foodItemListTomorrow = findViewById(R.id.foodItemListTomorrow);
        foodItemListLater = findViewById(R.id.foodItemListLater);

        // saving stave of the first application start
        SharedPreferences ratePrefs = getSharedPreferences("FoodNoWaster_FirstStart", 0);
        if (!ratePrefs.getBoolean("FirstStart", false)) {

            // set alarm only during the very first application start
            setAlarm();
            SharedPreferences.Editor edit = ratePrefs.edit();
            edit.putBoolean("FirstStart", true);
            edit.commit();
        }
    }

    public void openAddModifyDeleteFoodItem(View view) {
        startActivity(new Intent(this, AddModifyDeleteFoodItem.class));
    }


    @Override
    public void onResume() {
        super.onResume();
        populateData();
    }


    public void populateData() {
        mydb = new DBHelper(this);

        runOnUiThread(new Runnable() {
            public void run() {
                fetchDataFromDB();
            }
        });
    }


    public void fetchDataFromDB() {
        todayList.clear();
        tomorrowList.clear();
        laterList.clear();

        Cursor today = mydb.getTodayFoodItem();
        Cursor tomorrow = mydb.getTomorrowFoodItem();
        Cursor later = mydb.getLaterFoodItem();

        loadDataList(today, todayList);
        loadDataList(tomorrow, tomorrowList);
        loadDataList(later, laterList);


        if (todayList.isEmpty() && tomorrowList.isEmpty() && laterList.isEmpty()) {
            empty.setVisibility(View.VISIBLE);
            scrollView.setVisibility(View.GONE);
        } else {
            empty.setVisibility(View.GONE);
            scrollView.setVisibility(View.VISIBLE);

            if (todayList.isEmpty()) {
                todayContainer.setVisibility(View.GONE);
            } else {
                todayContainer.setVisibility(View.VISIBLE);
                loadListView(foodItemListToday, todayList);
            }

            if (tomorrowList.isEmpty()) {
                tomorrowContainer.setVisibility(View.GONE);
            } else {
                tomorrowContainer.setVisibility(View.VISIBLE);
                loadListView(foodItemListTomorrow, tomorrowList);
            }

            if (laterList.isEmpty()) {
                laterContainer.setVisibility(View.GONE);
            } else {
                laterContainer.setVisibility(View.VISIBLE);
                loadListView(foodItemListLater, laterList);
            }
        }
    }


    public void loadDataList(Cursor cursor, ArrayList<HashMap<String, String>> dataList) {
        if (cursor != null) {
            cursor.moveToFirst();
            while (cursor.isAfterLast() == false) {

                HashMap<String, String> mapToday = new HashMap<String, String>();
                mapToday.put("id", cursor.getString(0).toString());
                mapToday.put("foodItem", cursor.getString(1).toString());
                mapToday.put("expirationDate", cursor.getString(2).toString());
                mapToday.put("status", cursor.getString(3).toString());
                dataList.add(mapToday);
                cursor.moveToNext();
            }
        }
    }

    public void loadListView(NoScrollListView listView, final ArrayList<HashMap<String, String>> dataList) {
        ListFoodItemAdapter adapter = new ListFoodItemAdapter(this, dataList, mydb);
        listView.setAdapter(adapter);
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            public void onItemClick(AdapterView<?> parent, View view,
                                    int position, long id) {
                Intent i = new Intent(MainActivity.this, AddModifyDeleteFoodItem.class);
                i.putExtra("isModify", true);
                i.putExtra("id", dataList.get(+position).get("id"));
                startActivity(i);
            }
        });
    }

    //setting repeating alarm
    private void setAlarm() {
        //getting the alarm manager
        AlarmManager alarmMgr = (AlarmManager) getSystemService(Context.ALARM_SERVICE);

        //creating a new intent specifying the broadcast receiver
        Intent intent = new Intent(this, MyAlarm.class);

        //creating a pending intent using the intent
        PendingIntent alarmIntent = PendingIntent.getBroadcast(this, 0, intent, 0);

        // Set the alarm to start at 9:00 a.m.
        Calendar calendar = Calendar.getInstance();
        calendar.setTimeInMillis(System.currentTimeMillis());
        calendar.set(Calendar.HOUR_OF_DAY, 9);
        calendar.set(Calendar.MINUTE, 00);

        //repeat alarm daily
        alarmMgr.setRepeating(AlarmManager.RTC, calendar.getTimeInMillis(),
                60000 * 60 * 24, alarmIntent);

    }
}
